@@ -235,10 +235,12 @@ class Client:
         ```origin_dir_name``` is a directory path (```dirA/dirB/dirC```). This path triggers
         the creation of the corresponding collections and sub-collections in Jama.
         """
-        upload_infos = self.upload_infos(_file_hash256(file_path), project_id=project_id)
+        upload_infos = self.upload_infos(
+            _file_hash256(file_path), project_id=project_id
+        )
         if upload_infos.get("status") == "available":
             return upload_infos.get("id")
-            #raise AlreadyUploaded()
+            # raise AlreadyUploaded()
 
         chunked_upload = _ChunksUploader(
             file_path,
@@ -276,13 +278,9 @@ class Client:
         """
         return self.__call("activate_rpc_access", [user_name, api_key])
 
-    def add_collection(
-        self, title: str, parent_id: int = None, project_id: int = None
-    ) -> Optional[Dict]:
+    def add_collection(self, title: str, parent_id: int) -> Dict:
         """
-        Create a new collection based on 'title'. If 'parent_id' is set,
-        will create new collection as child of parent. Otherwise, project_id
-        is needed to create the new collection at the project's root.
+        Create a new collection based on 'title' and parent_id
 
         Returns either the serialized new collection of null if parent does
         not exist.
@@ -306,7 +304,7 @@ class Client:
         }
         ```
         """
-        return self.__call("add_collection", [title, parent_id, project_id])
+        return self.__call("add_collection", [title, parent_id])
 
     def add_collection_from_path(self, path: str, project_id: int) -> List[Dict]:
         """
@@ -369,18 +367,21 @@ class Client:
         return self.__call("add_collection_from_path", [path, project_id])
 
     def add_meta_to_collection(
-        self, collection_id: int, meta_id: int, meta_value: str
-    ) -> Union[int, bool]:
+        self, collection_id: int, meta_id: int, meta_value: str, cascade: bool = False
+    ) -> int:
         """
         Add a meta value to a collection given their ids.
+
+        If cascade is True, the meta will be added to all descendants,
+        collections and resources alike.
         """
         return self.__call(
-            "add_meta_to_collection", [collection_id, meta_id, meta_value]
+            "add_meta_to_collection", [collection_id, meta_id, meta_value, cascade]
         )
 
     def add_meta_to_resource(
         self, resource_id: int, meta_id: int, meta_value: str
-    ) -> Union[int, bool]:
+    ) -> int:
         """
         Add a meta value to a resource given their ids.
         """
@@ -388,11 +389,11 @@ class Client:
 
     def add_metadata(
         self, title: str, metas_set_id: int, metadata_type_id: int = None
-    ) -> Union[int, bool]:
+    ) -> int:
         """
         Add a new metadata to metadata set.
 
-        Set optional 'metadata_type_id'
+        Set optional 'metadata_type_id'. Defaults to string type.
         """
         return self.__call("add_metadata", [title, metas_set_id, metadata_type_id])
 
@@ -421,7 +422,14 @@ class Client:
         return self.__call("add_tag_to_resource", [tag_uid, resource_id])
 
     def advanced_search(
-        self, search_terms: List[Dict], project_id: int
+        self,
+        search_terms: List[Dict],
+        project_id: int,
+        include_metas: bool = False,
+        collection_id: int = None,
+        limit_from: int = 0,
+        limit_to: int = 2000,
+        order_by: str = "title",
     ) -> Dict[str, List]:
         """
         Performs a complex search using terms such as 'contains', 'is', 'does_not_contain'.
@@ -434,7 +442,9 @@ class Client:
         [
             {"property": "title", "term": "contains", "value": "cherbourg"},
             {"meta": 123, "term": "is", "value": "35mm"},
+            {"exclude_meta": 145},
             {"tags": ["PAINTINGS", "PHOTOS"]}
+            {"exclude_tags": ["DRAWINGS"]}
         ]
         ```
 
@@ -458,7 +468,18 @@ class Client:
         }
         ```
         """
-        return self.__call("advanced_search", [search_terms, project_id])
+        return self.__call(
+            "advanced_search",
+            [
+                search_terms,
+                project_id,
+                include_metas,
+                collection_id,
+                limit_from,
+                limit_to,
+                order_by,
+            ],
+        )
 
     def advanced_search_terms(self) -> List[str]:
         """
@@ -596,9 +617,7 @@ class Client:
         """
         return self.__call("change_resource_meta_value", [meta_value_id, meta_value])
 
-    def collection(
-        self, collection_id: int = None, project_id: int = None
-    ) -> Optional[Dict]:
+    def collection(self, collection_id: int) -> Dict:
         """
         Get a particular collection given its id.
 
@@ -610,8 +629,6 @@ class Client:
             "title": "art works",
             "resources_count": 23,
             "children_count": 5,
-            "descendants_count": 12,
-            "descendants_resources_count": 58,
             "parent": 1,
             "children": None,
             "metas": [],
@@ -619,34 +636,34 @@ class Client:
             "tags": [],
         }
         ```
-
-        if collection id is null, will only return the number of collections at root
-        for the given project_id:
-
-        ```
-        {
-            "id": None,
-            "title": "root",
-            "children_count": 25,
-        }
-        ```
         """
-        return self.__call("collection", [collection_id, project_id])
+        return self.__call("collection", [collection_id])
+
+    def collection_stats(self, collection_id: int) -> dict:
+        """
+        Get infos from given collection:
+
+        - number of descendants
+        - number of descendant resources
+        - number of resources
+        - number of children collections
+        """
+        return self.__call("collection_stats", [collection_id])
 
     def collections(
         self,
-        parent_id: int = None,
+        parent_id: int,
         recursive: bool = False,
         limit_from: int = 0,
         limit_to: int = 2000,
         flat_list: bool = False,
         only_published: bool = False,
-        project_id: int = None,
+        order_by: str = "title",
+        only_deleted_items: bool = False,
     ) -> List[Dict]:
         """
         Return the user's collections under the parent collection
-        specified by 'parent_id'. If 'parent_id' is null, will return
-        collections available at root. If 'recursive' is true, will
+        specified by 'parent_id'. If 'recursive' is true, will
         return all the descendants recursively in the 'children' key.
         If recursive is false, 'children' is null. If flat_list is True,
         collections are returned as a flat list and parent_id is ignored.
@@ -680,7 +697,8 @@ class Client:
                 limit_to,
                 flat_list,
                 only_published,
-                project_id,
+                order_by,
+                only_deleted_items,
             ],
         )
 
@@ -793,7 +811,7 @@ class Client:
         """
         return self.__call("list_roles", [project_id])
 
-    def metadata(self, metadata_id: int) -> Optional[Dict]:
+    def metadata(self, metadata_id: int) -> Dict:
         """
         Get one particular metadata given its id.
 
@@ -875,23 +893,36 @@ class Client:
         return self.__call("metadatatypes", [])
 
     def move_collection(
-        self, child_collection_id: int, parent_collection_id: int = None
+        self, child_collection_id: int, parent_collection_id: int
     ) -> bool:
         """
         Move a collection from a parent to another.
 
-        Will return false in the following cases:
+        Will raise ServiceException in the following cases:
 
         - 'child_collection_id' and 'parent_collection_id' are equal
         - parent collection does not exist
         - parent collection is a descendant of child collection
-
-        If 'parent_collection_id' is null, collection is moved to the root.
         """
         return self.__call(
             "move_collection", [child_collection_id, parent_collection_id]
         )
 
+    def move_items(
+        self,
+        from_collection_id: int,
+        to_collection_id: int,
+        collections_ids: List[int],
+        resources_ids: List[int],
+    ) -> Dict[str, Dict]:
+        """
+        Move items (collections or resources) from one Collection to another
+        """
+        return self.__call(
+            "move_items",
+            [from_collection_id, to_collection_id, collections_ids, resources_ids],
+        )
+
     def ping(self) -> str:
         """
         This is a test method to ensure the server-client communication works.
@@ -905,6 +936,44 @@ class Client:
         """
         return self.__call("ping", [])
 
+    def project_items(
+        self,
+        search_terms: List[Dict],
+        project_id: int,
+        include_metas: bool = False,
+        collection_id: int = None,
+        limit_from: int = 0,
+        limit_to: int = 2000,
+        order_by: str = "title",
+    ) -> Dict[str, List]:
+        """
+        Alias to advanced_search.
+        """
+        return self.__call(
+            "project_items",
+            [
+                search_terms,
+                project_id,
+                include_metas,
+                collection_id,
+                limit_from,
+                limit_to,
+                order_by,
+            ],
+        )
+
+    def project_stats(self, project_id: int) -> dict:
+        """
+        Get infos from given project:
+
+        - id of project collection root
+        - number of descendants
+        - number of descendant resources
+        - number of resources
+        - number of children collections
+        """
+        return self.__call("project_stats", [project_id])
+
     def projects_user_permissions(self) -> List[Dict]:
         """
         Get all rights for the current user.
@@ -929,11 +998,22 @@ class Client:
         """
         return self.__call("publish_collection", [collection_id])
 
+    def recycle_bin(self, project_id: int) -> List[Dict]:
+        """
+        Gets deleted elements:
+
+        - object type
+        - label
+        - id
+        - deleted_at
+        """
+        return self.__call("recycle_bin", [project_id])
+
     def remove_meta_from_collection(
         self, collection_id: int, meta_value_id: int
     ) -> bool:
         """
-        Remove a meta from a collection given their ids.
+        DEPRECATED. Use remove_meta_value_from_collection instead.
         """
         return self.__call(
             "remove_meta_from_collection", [collection_id, meta_value_id]
@@ -941,10 +1021,20 @@ class Client:
 
     def remove_meta_from_resource(self, resource_id: int, meta_value_id: int) -> bool:
         """
-        Remove a meta from a resource given their ids.
+        Remove a meta_value from a resource given their ids.
         """
         return self.__call("remove_meta_from_resource", [resource_id, meta_value_id])
 
+    def remove_meta_value_from_collection(
+        self, collection_id: int, meta_value_id: int
+    ) -> bool:
+        """
+        Remove a meta value from a collection given their ids.
+        """
+        return self.__call(
+            "remove_meta_value_from_collection", [collection_id, meta_value_id]
+        )
+
     def remove_resource_from_collection(
         self, resource_id: int, collection_id: int
     ) -> bool:
@@ -1003,7 +1093,7 @@ class Client:
         """
         return self.__call("replace_file", [from_resource_id, to_resource_id])
 
-    def resource(self, resource_id: int) -> Optional[Dict]:
+    def resource(self, resource_id: int) -> Dict:
         """
         Get a resource given its id.
 
@@ -1030,6 +1120,9 @@ class Client:
         include_metas: bool = False,
         limit_from: int = 0,
         limit_to: int = 2000,
+        order_by: str = "title",
+        only_deleted_items: bool = False,
+        only_tags: List[str] = None,
     ) -> List[Dict]:
         """
         Get all resources from a collection.
@@ -1058,9 +1151,30 @@ class Client:
         ```
         """
         return self.__call(
-            "resources", [collection_id, include_metas, limit_from, limit_to]
+            "resources",
+            [
+                collection_id,
+                include_metas,
+                limit_from,
+                limit_to,
+                order_by,
+                only_deleted_items,
+                only_tags,
+            ],
         )
 
+    def restore_collection(self, collection_id: int) -> bool:
+        """
+        Restore a deleted collection from the recycle bin
+        """
+        return self.__call("restore_collection", [collection_id])
+
+    def restore_resource(self, resource_id: int) -> bool:
+        """
+        Restore a deleted resource from the recycle bin
+        """
+        return self.__call("restore_resource", [resource_id])
+
     def set_is_oai_record(self, collection_id: int, is_oai_record: bool = True) -> bool:
         """
         Set/unset the collection as a OAI-PMH record. The creation date
@@ -1068,6 +1182,31 @@ class Client:
         """
         return self.__call("set_is_oai_record", [collection_id, is_oai_record])
 
+    def set_metas_to_collection(
+        self, collection_id: int, metas: List[dict], cascade: bool = False
+    ) -> bool:
+        """
+        Sets all metas for a unique metadata set.
+
+        Metas is a list of metadata id => metadata value dictionaries.
+
+        All metas must share the same metadata set.
+
+        If cascade is True, the meta will be added to all descendants,
+        collections and resources alike.
+        """
+        return self.__call("set_metas_to_collection", [collection_id, metas, cascade])
+
+    def set_metas_to_resource(self, resource_id: int, metas: List[dict]) -> bool:
+        """
+        Sets all metas for a unique metadata set.
+
+        Metas is a list of metadata id => metadata value dictionaries.
+
+        All metas must share the same metadata set.
+        """
+        return self.__call("set_metas_to_resource", [resource_id, metas])
+
     def set_representative_resource(
         self, collection_id: int, resource_id: int = None
     ) -> bool:
@@ -1110,7 +1249,14 @@ class Client:
         """
         return self.__call("set_tag", [uid, project_id, label, ark])
 
-    def simple_search(self, query: str, project_id: int) -> Dict[str, List]:
+    def simple_search(
+        self,
+        query: str,
+        project_id: int,
+        limit_from: int = 0,
+        limit_to: int = 2000,
+        order_by: str = "title",
+    ) -> Dict[str, List]:
         """
         Performs a simple search on resources and collections, based on their titles.
 
@@ -1148,7 +1294,9 @@ class Client:
         }
         ```
         """
-        return self.__call("simple_search", [query, project_id])
+        return self.__call(
+            "simple_search", [query, project_id, limit_from, limit_to, order_by]
+        )
 
     def supported_file_types(self) -> List[Dict]:
         """
